#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aws
version:              0.24.2
visibility:           public
id:                   aws-0.24.2-JvaD2N7JJgYE9IFfClnlVj
key:                  aws-0.24.2-JvaD2N7JJgYE9IFfClnlVj
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  eaa913c86a7d7cf11556f3cfccd64a06
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/aws-0.24.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aws
hs-libraries:         HSaws-0.24.2-JvaD2N7JJgYE9IFfClnlVj
depends:
    aeson-2.2.1.0-ISVQ3jiqbQ6Is6pNVe1jQU
    attoparsec-0.14.4-KNfQqNYdh75Ctqov7zDdKZ
    attoparsec-aeson-2.2.0.0-9HkXkPt6Dm2KF6qCaUQtnC base-4.18.2.1
    base16-bytestring-1.0.2.0-2K2NwdE4gW3En3QIR8OMok
    base64-bytestring-1.2.1.0-FYGVETKTcLTBGzKt2AR5gJ
    blaze-builder-0.4.4.1-G3HtoHgubT6EOxrSsDfu5A
    byteable-0.1.1-3f80cduirhUG2oEjYYiPCW bytestring-0.11.5.3
    case-insensitive-1.2.1.0-Elzb0rAqwweFuDsBC4YYTB
    cereal-0.5.8.3-9zr3eQnzv374L09nXO1NoK
    conduit-1.3.6.1-IWqUZ7RVwZqJ8eWatAjUwv
    conduit-extra-1.3.8-5lvtlSpJrZxATkM3BZIrG containers-0.6.7
    cryptonite-0.30-FSsVAXZn8WtAF9x9npkm3j
    data-default-0.7.1.3-Jbl1GQbSIet3IvhyjwA92u directory-1.3.8.5
    exceptions-0.10.7 filepath-1.4.300.1
    http-client-tls-0.3.6.4-83uPLl4XmnQ70LpGBZLm3L
    http-conduit-2.3.9.1-2xFlR22CgAkEnRwNHRK5
    http-types-0.12.4-ANoVLVnxqrbENrwWDaCdfA
    lifted-base-0.2.3.12-9vOp2gUySroABkPgPCHikK
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    monad-control-1.0.3.1-IuJstzkI5rwIrPJC6eCMb3 mtl-2.3.1
    network-3.1.4.0-3WVMCxWJjSRIlAlOqOkCHy
    network-bsd-2.8.1.0-JwBzZhfh2OgJqyavIXVcih
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    resourcet-1.2.6-I5BvQNSXhsg7IJ48MRbKfA
    safe-0.3.21-64nzpApG3S1GIGiW5EQIjs
    scientific-0.3.8.1-CPW4CBoKM8kEEiILcscWDQ
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2 time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-9qQGbgjzyj0ISlxTMt28N2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    vector-0.13.2.0-EpP5e7pcZ78KLpeNqLEk9O
    xml-conduit-1.9.1.4-COwdD4l0CfELcyRXtFYRtK

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

